@@ -59,4 +59,7 @@ def _same_properties(value: dict, props: List[str]):
 def _average(value, default=0): return mean(value) if value is not None and isinstance(value, list) else default
 
 
-def _value_average(node: dict, default=0): return _average(node.get('value'), default)
+def _value_average(node: dict, default=0):
+    value = node.get('value')
+    is_number = value is not None and (isinstance(value, float) or isinstance(value, int))
+    return value if is_number else _average(value, default)
