@@ -1,6 +1,7 @@
 from hestia_earth.schema import CycleFunctionalUnitMeasure, SiteSiteType
+from hestia_earth.utils.date import diff_in_days, is_in_days
 
-from hestia_earth.validation.utils import _list_has_props, _is_in_days, _diff_in_days, _get_dict_key, _flatten
+from hestia_earth.validation.utils import _list_has_props, _get_dict_key, _flatten
 from .shared import validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max, \
     validate_list_term_percent
 from .practice import validate_cropResidueManagement
@@ -23,11 +24,11 @@ def validate_cycle_dates(cycle: dict):
 
 
 def _should_validate_cycleDuration(cycle: dict):
-    return 'cycleDuration' in cycle and _is_in_days(cycle.get('startDate')) and _is_in_days(cycle.get('endDate'))
+    return 'cycleDuration' in cycle and is_in_days(cycle.get('startDate')) and is_in_days(cycle.get('endDate'))
 
 
 def validate_cycleDuration(cycle: dict):
-    duration = _diff_in_days(cycle.get('startDate'), cycle.get('endDate'))
+    duration = diff_in_days(cycle.get('startDate'), cycle.get('endDate'))
     return duration == round(cycle.get('cycleDuration'), 1) or {
         'level': 'error',
         'dataPath': '.cycleDuration',
@@ -61,22 +62,6 @@ def validate_relDays(cycle: dict, prop: str):
     return next((x for x in results if x is not True), True)
 
 
-def validate_altStartDate(cycle: dict):
-    return len(cycle.get('altStartDateDefinition', '')) > 0 or {
-        'level': 'error',
-        'dataPath': '.altStartDateDefinition',
-        'message': 'is required when using altStartDate'
-    }
-
-
-def validate_startDate(cycle: dict):
-    return len(cycle.get('altStartDate', '')) == 0 or {
-        'level': 'error',
-        'dataPath': '.altStartDate',
-        'message': 'cannot be used with startDate'
-    }
-
-
 def validate_cycle(cycle: dict):
     """
     Validates a single `Cycle`.
@@ -94,9 +79,7 @@ def validate_cycle(cycle: dict):
     return [
         validate_cycle_dates(cycle),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
-        validate_altStartDate(cycle) if 'altStartDate' in cycle else True,
-        validate_startDate(cycle) if 'startDate' in cycle else True,
-        validate_dataCompleteness(cycle.get('dataCompleteness'))
+        validate_dataCompleteness(cycle.get('dataCompleteness', {})) if 'dataCompleteness' in cycle else True
     ] + _flatten([
         validate_list_dates(cycle, 'emissions'),
         validate_list_min_max(cycle, 'emissions'),
