@@ -2,7 +2,8 @@ import unittest
 import json
 
 from tests.utils import fixtures_path
-from hestia_earth.validation.validators.measurement import validate_soilTexture, validate_depths, validate_value_min_max
+from hestia_earth.validation.validators.measurement import validate_soilTexture, validate_depths, \
+    validate_value_min_max, validate_term_unique
 
 
 class TestValidatorsMeasurement(unittest.TestCase):
@@ -99,3 +100,21 @@ class TestValidatorsMeasurement(unittest.TestCase):
             'dataPath': '.measurements[0].value',
             'message': 'should be above 0.0'
         })
+
+    def test_validate_term_unique_valid(self):
+        with open(f"{fixtures_path}/measurement/unique/valid.json") as f:
+            data = json.load(f)
+        self.assertEqual(validate_term_unique(data.get('nodes')), True)
+
+    def test_validate_term_unique_invalid(self):
+        with open(f"{fixtures_path}/measurement/unique/invalid.json") as f:
+            data = json.load(f)
+        self.assertEqual(validate_term_unique(data.get('nodes')), [{
+            'level': 'error',
+            'dataPath': '.measurements[0].term.name',
+            'message': 'must be unique'
+        }, {
+            'level': 'error',
+            'dataPath': '.measurements[1].term.name',
+            'message': 'must be unique'
+        }])
